@@ -7,12 +7,11 @@ from pybmd.timeline_item import TimelineItem
 
 from dataclasses import dataclass
 from dataclasses import asdict
-from multipledispatch import dispatch
 
 
 @dataclass
 class ClipInfo():
-    """Docstring for ClipInfo."""
+    """ClipInfo dataclass"""
     media_pool_item: MediaPoolItem
     start_frame: int
     end_frame: int
@@ -21,7 +20,7 @@ class ClipInfo():
 
 @dataclass
 class TimelineImportOptions():
-    """Docstring for TimelineImportOptions."""
+    """TimelineImportOptions dataclass"""
     timeline_name: str
     import_source_clips: str
     source_clips_path: str
@@ -29,25 +28,42 @@ class TimelineImportOptions():
     interlace_pricessing: bool
 
 
-def asdict_inside_list(list: list) -> list:
-    return_list = []
-    for value in list:
-        return_list.append(asdict(value))
-    return return_list
+# def asdict_inside_list(list: list) -> list:
+#     return_list = []
+#     for value in list:
+#         return_list.append(asdict(value))
+#     return return_list
 
 
 class MediaPool():
-    """docstring for MediaPool."""
+    """ MediaPool Object """
 
     def __init__(self, media_pool):
         self.media_pool = media_pool
 
     def add_sub_folder(self, folder: Folder, name: str) -> Folder:
+        """add sub folder to folder
+
+        Args:
+            folder (Folder): folder to add sub folder to 
+            name (str): name of new sub folder
+
+        Returns:
+            Folder: folder object of new sub folder
+        """        
         return Folder(self.media_pool.AddSubFolder(folder, name))
 
     # @dispatch(List[MediaPoolItem])
     # type: ignore
     def append_to_timeline(self, clips: List[MediaPoolItem]) -> List[TimelineItem]:
+        """append clips to current timeline
+
+        Args:
+            clips (List[MediaPoolItem]): clips to append to current timeline
+
+        Returns:
+            List[TimelineItem]: timeline items of appended clips at timeline
+        """
         if type(clips[0]) is MediaPoolItem:
             temp_list = self.media_pool.AppendToTimeline(
                 [clip.media_pool_item for clip in clips])
@@ -68,11 +84,21 @@ class MediaPool():
     #     return timeline_item_list
 
     def create_empty_timeline(self, name) -> Timeline:
+        """create empty timeline"""
         return Timeline(self.media_pool.CreateEmptyTimeline(name))
 
     # @dispatch(str, Iterable)
     # type: ignore
     def create_timeline_from_clips(self, name: str, clips) -> Timeline:
+        """create new timeline from clips with name
+
+        Args:
+            name (str): new timeline name
+            clips (_type_): clips to create timeline from
+
+        Returns:
+            Timeline: new timeline object
+        """
         if type(clips[0]) is MediaPoolItem:
             return Timeline(self.media_pool.CreateTimelineFromClips(name, [clip.media_pool_item for clip in clips]))
         elif type(clips[0]) is ClipInfo:
@@ -83,21 +109,50 @@ class MediaPool():
     #     return self.media_pool.CreateTimelineFromClips(name, [asdict(ClipInfo) for ClipInfo in clip_infos])
 
     def delete_clip_mattes(self, media_pool_item: MediaPoolItem, paths: List[str]) -> bool:
+        """Delete mattes based on their file paths for specified media pool item
+
+        Args:
+            media_pool_item (MediaPoolItem): meida pool item to delete mattes for
+            paths (List[str]): matte file paths to delete
+
+        Returns:
+            bool: true if successful, false if not
+        """
         return self.media_pool.DeleteClipMattes(media_pool_item, paths)
 
     def delete_clips(self, clips: List[MediaPoolItem]) -> bool:
+        """Delete clips from media pool"""
         return self.media_pool.DeleteClips([clip.media_pool_item for clip in clips])
 
     def delete_folders(self, subfolders: List[Folder]) -> bool:
+        """delete folders from media pool"""
         return self.media_pool.DeleteFolders([folder.folder for folder in subfolders])
 
     def delete_timelines(self, timelines: List[Timeline]) -> bool:
+        """delete timelines from media pool
+
+        Args:
+            timelines (List[Timeline]): list of timelines to delete
+
+        Returns:
+            bool: true if successful, false if not
+        """
         return self.media_pool.DeleteTimelines([timeline.timeline for timeline in timelines])
 
     def export_metadata(self, file_name: str, clips: List[MediaPoolItem]) -> bool:
+        """export metadata to csv file
+
+        Args:
+            file_name (str): export metadata csv file name
+            clips (List[MediaPoolItem]): clips to export metadata for If no clips are specified, all clips from media pool will be used.
+
+        Returns:
+            bool: True if successful, False if not
+        """
         return self.media_pool.ExportMetadata(file_name, [clip.media_pool_item for clip in clips])
 
     def get_clip_matte_list(self, media_pool_item) -> List[Path]:
+        """get list of clip mattes for specified media pool item"""
         path_list = []
         for str_path in self.media_pool.GetClipMatteList(media_pool_item):
             path_list.append(Path(str_path))
@@ -147,3 +202,13 @@ class MediaPool():
 
     def unlink_clips(self, media_pool_items: List[MediaPoolItem]) -> bool:
         return self.media_pool.UnlinkClips([clip.media_pool_item for clip in media_pool_items])
+    
+    ##########################################################################################################################
+    #Add at DR18.0.0
+    def refresh_folders(self) -> bool:
+        return self.media_pool.RefreshFolders()
+    
+    def get_unique_id(self) -> str:
+        return self.media_pool.GetUniqueId()
+    
+    #########################################################################################################################
\ No newline at end of file
