@@ -1,9 +1,8 @@
 from enum import Enum
 from os import path
-from textwrap import dedent
 from typing import List
 
-from pybmd.gallerystill import GalleryStill
+from pybmd.gallery_still import GalleryStill
 from pybmd.timeline_item import TimelineItem
 
 
@@ -78,7 +77,7 @@ class Timeline():
         return Timeline(timeline=self.timeline.DuplicateTimeline(timeline_name))
 
     def export(self, file_name: str, export_type, export_subtype=None) -> bool:
-        #file_name should be a path, not a file name.  
+        # file_name should be a path, not a file name.
         # eg. file_path=os.path.join(os.path.expanduser("~"), "Desktop/Temp/sampleExp.drt")
         #     timeline.export(file_path,LOCAL_RESOLVE.EXPORT_DRT)
         return self.timeline.Export(file_name, export_type, export_subtype)
@@ -169,3 +168,20 @@ class Timeline():
 
     def update_marker_custom_data(self, frame_id: int, custom_data: str) -> bool:
         return self.timeline.UpdateMarkerCustomData(frame_id, custom_data)
+
+    #######################################################################################################################
+    # Add at DR18.0.0
+    
+    def set_start_timecode(self, timecode: str) -> bool:
+        return self.timeline.SetStartTimecode(timecode)
+
+    def get_start_timecode(self) -> str:
+        return self.timeline.GetStartTimecode()
+    
+    def insert_fusion_composition_into_timeline(self) -> TimelineItem:
+        return TimelineItem(self.timeline.InsertFusionCompositionIntoTimeline())
+    
+    def get_unique_id(self) -> str:
+        return self.timeline.GetUniqueId()
+    
+    #######################################################################################################################
\ No newline at end of file
